@@ -4,23 +4,30 @@ set -eu
 declare -A PKG_MAP
 
 CHECK_CMD_PKGS=(
+    gcc
     libffi
     libopenssl
+    lsb-release
+    make
     net-tools
     python-devel
+    python
+    venv
+    wget
 )
 
 # Check zypper before apt-get in case zypper-aptitude
 # is installed
 if [ -x '/usr/bin/zypper' ]; then
     OS_FAMILY="Suse"
-    INSTALLER_CMD="sudo -H zypper install -y"
+    INSTALLER_CMD="sudo -H -E zypper install -y --no-recommends"
     CHECK_CMD="zypper search --match-exact --installed"
     PKG_MAP=(
         [gcc]=gcc
-        [git]=git
         [libffi]=libffi-devel
         [libopenssl]=libopenssl-devel
+        [lsb-release]=lsb-release
+        [make]=make
         [net-tools]=net-tools
         [python]=python
         [python-devel]=python-devel
@@ -35,38 +42,50 @@ if [ -x '/usr/bin/zypper' ]; then
     fi
 elif [ -x '/usr/bin/apt-get' ]; then
     OS_FAMILY="Debian"
-    INSTALLER_CMD="sudo -H apt-get -y install"
+    INSTALLER_CMD="sudo -H -E apt-get -y install"
     CHECK_CMD="dpkg -l"
-    PKG_MAP=( [gcc]=gcc
-              [git]=git
-              [libffi]=libffi-dev
-              [libopenssl]=libssl-dev
-              [net-tools]=net-tools
-              [python]=python-minimal
-              [python-devel]=libpython-dev
-              [venv]=python-virtualenv
-              [wget]=wget
-            )
+    PKG_MAP=(
+        [gcc]=gcc
+        [libffi]=libffi-dev
+        [libopenssl]=libssl-dev
+        [lsb-release]=lsb-release
+        [make]=make
+        [net-tools]=net-tools
+        [python]=python-minimal
+        [python-devel]=libpython-dev
+        [venv]=python-virtualenv
+        [wget]=wget
+    )
     EXTRA_PKG_DEPS=()
 elif [ -x '/usr/bin/dnf' ] || [ -x '/usr/bin/yum' ]; then
     OS_FAMILY="RedHat"
     PKG_MANAGER=$(which dnf || which yum)
-    INSTALLER_CMD="sudo -H ${PKG_MANAGER} -y install"
+    INSTALLER_CMD="sudo -H -E ${PKG_MANAGER} -y install"
     CHECK_CMD="rpm -q"
     PKG_MAP=(
         [gcc]=gcc
-        [git]=git
         [libffi]=libffi-devel
         [libopenssl]=openssl-devel
+        [lsb-release]=redhat-lsb
+        [make]=make
         [net-tools]=net-tools
         [python]=python
         [python-devel]=python-devel
         [venv]=python-virtualenv
         [wget]=wget
     )
-    EXTRA_PKG_DEPS=( epel-release )
+    EXTRA_PKG_DEPS=()
 else
-    echo "ERROR: Supported package manager not found.  Supported: apt,yum,zypper"
+    echo "ERROR: Supported package manager not found.  Supported: apt, dnf, yum, zypper"
+fi
+
+# if running in OpenStack CI, then make sure epel is enabled
+# since it may already be present (but disabled) on the host
+if env | grep -q ^ZUUL; then
+    if [[ -x '/usr/bin/yum' ]]; then
+        ${INSTALLER_CMD} yum-utils
+        sudo yum-config-manager --enable epel || true
+    fi
 fi
 
 if ! $(python --version &>/dev/null); then
@@ -75,14 +94,11 @@ fi
 if ! $(gcc -v &>/dev/null); then
     ${INSTALLER_CMD} ${PKG_MAP[gcc]}
 fi
-if ! $(git --version &>/dev/null); then
-    ${INSTALLER_CMD} ${PKG_MAP[git]}
-fi
 if ! $(wget --version &>/dev/null); then
     ${INSTALLER_CMD} ${PKG_MAP[wget]}
 fi
 if [ -n "${VENV-}" ]; then
-    if $(virtualenv --version &>/dev/null); then
+    if ! $(python -m virtualenv --version &>/dev/null); then
         ${INSTALLER_CMD} ${PKG_MAP[venv]}
     fi
 fi
@@ -105,7 +121,7 @@ if [ -n "${VENV-}" ]; then
     echo "NOTICE: Using virtualenv for this installation."
     if [ ! -f ${VENV}/bin/activate ]; then
         # only create venv if one doesn't exist
-        sudo -H -E virtualenv --no-site-packages ${VENV}
+        sudo -H -E python -m virtualenv --no-site-packages ${VENV}
     fi
     # Note(cinerama): activate is not compatible with "set -u";
     # disable it just for this line.
@@ -150,3 +166,9 @@ PIP=$(which pip)
 
 sudo -H -E ${PIP} install "pip>6.0"
 sudo -H -E ${PIP} install -r "$(dirname $0)/../requirements.txt"
+
+# Install the rest of required packages using bindep
+sudo -H -E ${PIP} install bindep
+
+# bindep returns 1 if packages are missing
+bindep -b &> /dev/null || ${INSTALLER_CMD} $(bindep -b)
